# Generated by roxygen2: do not edit by hand

S3method(glance,maihda_analysis)
S3method(glance,maihda_model)
S3method(glance,maihda_summary)
S3method(plot,maihda_analysis)
S3method(plot,maihda_comparison)
S3method(plot,maihda_group_comparison)
S3method(plot,maihda_model)
S3method(plot,maihda_ternary)
S3method(print,maihda_analysis)
S3method(print,maihda_da)
S3method(print,maihda_group_comparison)
S3method(print,maihda_ic)
S3method(print,maihda_interactions)
S3method(print,maihda_long_pcv)
S3method(print,maihda_model)
S3method(print,maihda_stepwise)
S3method(print,maihda_strata)
S3method(print,maihda_summary)
S3method(print,maihda_table)
S3method(print,maihda_vpc_response)
S3method(print,pvc_result)
S3method(summary,maihda_analysis)
S3method(summary,maihda_model)
S3method(tidy,maihda_analysis)
S3method(tidy,maihda_model)
S3method(tidy,maihda_summary)
export(calculate_pvc)
export(compare_maihda)
export(compare_maihda_groups)
export(compute_maihda_ternary_data)
export(fit_maihda)
export(glance)
export(maihda)
export(maihda_auc)
export(maihda_cumulative)
export(maihda_discriminatory_accuracy)
export(maihda_ic)
export(maihda_interactions)
export(maihda_mor)
export(maihda_table)
export(maihda_ternary_plot)
export(maihda_vpc_response)
export(make_strata)
export(plot_comparison)
export(plot_group_comparison)
export(plot_maihda_ternary)
export(plot_prediction_deviation_panels)
export(predict_maihda)
export(run_maihda_app)
export(stepwise_pcv)
export(tidy)
import(dplyr)
import(ggplot2)
import(ggrepel)
import(patchwork)
import(tidyr)
importFrom(dplyr,across)
importFrom(dplyr,all_of)
importFrom(dplyr,arrange)
importFrom(dplyr,as_tibble)
importFrom(dplyr,bind_rows)
importFrom(dplyr,desc)
importFrom(dplyr,distinct)
importFrom(dplyr,group_by)
importFrom(dplyr,left_join)
importFrom(dplyr,mutate)
importFrom(dplyr,n)
importFrom(dplyr,row_number)
importFrom(dplyr,select)
importFrom(dplyr,slice)
importFrom(dplyr,summarise)
importFrom(dplyr,ungroup)
importFrom(dplyr,where)
importFrom(generics,glance)
importFrom(generics,tidy)
importFrom(lme4,VarCorr)
importFrom(lme4,fixef)
importFrom(lme4,glmer)
importFrom(lme4,lmer)
importFrom(lme4,ranef)
importFrom(lme4,refit)
importFrom(reformulas,findbars)
importFrom(reformulas,nobars)
importFrom(rlang,.data)
importFrom(rlang,check_installed)
importFrom(rlang,enquos)
importFrom(rlang,eval_tidy)
importFrom(stats,AIC)
importFrom(stats,BIC)
importFrom(stats,as.formula)
importFrom(stats,binomial)
importFrom(stats,fitted)
importFrom(stats,formula)
importFrom(stats,gaussian)
importFrom(stats,logLik)
importFrom(stats,median)
importFrom(stats,model.frame)
importFrom(stats,na.omit)
importFrom(stats,p.adjust)
importFrom(stats,p.adjust.methods)
importFrom(stats,pnorm)
importFrom(stats,poisson)
importFrom(stats,predict)
importFrom(stats,qnorm)
importFrom(stats,quantile)
importFrom(stats,residuals)
importFrom(stats,setNames)
importFrom(stats,terms)
importFrom(stats,update)
importFrom(tidyr,unite)
importFrom(utils,head)
importFrom(utils,tail)
