% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/summary_maihda.R
\name{add_stratum_labels}
\alias{add_stratum_labels}
\title{Add Stratum Labels to Estimates}
\usage{
add_stratum_labels(stratum_estimates, strata_info)
}
\arguments{
\item{stratum_estimates}{Data frame with stratum estimates}

\item{strata_info}{Data frame with stratum information including labels}
}
\value{
Data frame with labels merged in
}
\description{
Internal helper function to merge stratum labels into stratum estimates.
}
\keyword{internal}
