% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/MAIHDA-package.R
\docType{package}
\name{MAIHDA-package}
\alias{MAIHDA}
\alias{MAIHDA-package}
\title{MAIHDA: Multilevel Analysis of Individual Heterogeneity and Discriminatory Accuracy}
\description{
\if{html}{\figure{logo.png}{options: style='float: right' alt='logo' width='120'}}

Provides a comprehensive toolkit for conducting Multilevel Analysis of Individual Heterogeneity and Discriminatory Accuracy (MAIHDA). Methods are described in Merlo (2018) \doi{10.1016/j.socscimed.2017.12.018} and Evans et al. (2018) \doi{10.1016/j.socscimed.2017.11.011}. Automatically generates intersectional strata, fits analytical models, extracts statistics, and produces visualizations.
}
\seealso{
Useful links:
\itemize{
  \item \url{https://github.com/hdbt/MAIHDA}
  \item \url{https://hdbt.github.io/MAIHDA/}
  \item Report bugs at \url{https://github.com/hdbt/MAIHDA/issues}
}

}
\author{
\strong{Maintainer}: Hamid Bulut \email{me@hamidbulut.com}

}
\keyword{internal}
