% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/calculate_pvc.R
\name{bootstrap_pvc}
\alias{bootstrap_pvc}
\title{Bootstrap PVC}
\usage{
bootstrap_pvc(model1, model2, n_boot, conf_level)
}
\arguments{
\item{model1}{First maihda_model object}

\item{model2}{Second maihda_model object}

\item{n_boot}{Number of bootstrap samples}

\item{conf_level}{Confidence level}
}
\value{
A vector with lower and upper confidence bounds
}
\description{
Internal function to compute bootstrap confidence intervals for PVC.
}
\keyword{internal}
