% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/plot_maihda.R
\name{plot_obs_vs_shrunken}
\alias{plot_obs_vs_shrunken}
\title{Observed vs. Shrunken Estimates Plot}
\usage{
plot_obs_vs_shrunken(object, summary_obj)
}
\arguments{
\item{object}{A maihda_model object}

\item{summary_obj}{A maihda_summary object}
}
\value{
A ggplot2 object
}
\description{
Observed vs. Shrunken Estimates Plot
}
\keyword{internal}
