% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/plot_maihda.R
\name{plot_predicted_strata}
\alias{plot_predicted_strata}
\title{Plot Predicted Stratum Values with Confidence Intervals}
\usage{
plot_predicted_strata(
  object,
  summary_obj,
  n_strata,
  scale = c("response", "link")
)
}
\arguments{
\item{object}{A maihda_model object}

\item{summary_obj}{A maihda_summary object}

\item{n_strata}{Maximum number of strata to display}

\item{scale}{Prediction scale: "response" (default) or "link"}
}
\value{
A ggplot2 object
}
\description{
Plot Predicted Stratum Values with Confidence Intervals
}
\keyword{internal}
