% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/plot_maihda.R
\name{plot_vpc}
\alias{plot_vpc}
\title{VPC Visualization Plot}
\usage{
plot_vpc(summary_obj)
}
\arguments{
\item{summary_obj}{A maihda_summary object}
}
\value{
A ggplot2 object
}
\description{
VPC Visualization Plot
}
\keyword{internal}
