% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/maihda_ternary.R
\name{maihda_ternary_plot}
\alias{maihda_ternary_plot}
\title{Generate Ternary Plot from MAIHDA Model}
\usage{
maihda_ternary_plot(model, summary_obj = NULL, ...)
}
\arguments{
\item{model}{A fitted MAIHDA model.}

\item{summary_obj}{Optional output from \code{summary_maihda}.}

\item{...}{Additional arguments passed to \code{compute_maihda_ternary_data} and \code{plot_maihda_ternary}.}
}
\value{
A list containing \code{data} and \code{plot}.
}
\description{
Generate Ternary Plot from MAIHDA Model
}
