% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/maihda_ternary.R
\name{plot_maihda_ternary}
\alias{plot_maihda_ternary}
\title{Plot MAIHDA Ternary Diagram}
\usage{
plot_maihda_ternary(
  ternary_data,
  size_var = "n",
  color_var = "label",
  label_top_n = 5,
  label_by = c("interaction_signal", "uncertainty", "n"),
  alpha = 0.7
)
}
\arguments{
\item{ternary_data}{Data output from \code{compute_maihda_ternary_data}.}

\item{size_var}{Column name for point sizing.}

\item{color_var}{Column name for point colors.}

\item{label_top_n}{Number of top strata to label.}

\item{label_by}{Variable used to determine top strata.}

\item{alpha}{Point transparency.}
}
\value{
A plot object.
}
\description{
Plot MAIHDA Ternary Diagram
}
