% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/run_app.R
\name{run_maihda_app}
\alias{run_maihda_app}
\title{Run MAIHDA Shiny Application}
\usage{
run_maihda_app()
}
\value{
No return value, called to launch the shiny app.
}
\description{
Launches a Shiny graphical user interface that exposes core functions of the
MAIHDA package, allowing for visual data exploration, model fitting, and
performance visualization.
}
\examples{
\dontrun{
run_maihda_app()
}
}
