% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/summary_maihda.R
\name{bootstrap_vpc}
\alias{bootstrap_vpc}
\title{Bootstrap VPC/ICC}
\usage{
bootstrap_vpc(model, data, formula, n_boot, conf_level)
}
\arguments{
\item{model}{An lme4 model object}

\item{data}{The data used to fit the model}

\item{formula}{The model formula}

\item{n_boot}{Number of bootstrap samples}

\item{conf_level}{Confidence level}
}
\value{
A vector with lower and upper confidence bounds
}
\description{
Internal function to compute bootstrap confidence intervals for VPC.
}
\keyword{internal}
