% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/plot_maihda.R
\name{plot_effect_decomposition}
\alias{plot_effect_decomposition}
\title{Effect Decomposition Plot}
\usage{
plot_effect_decomposition(object, summary_obj, top_n_labels = 10)
}
\arguments{
\item{object}{A maihda_model object}

\item{summary_obj}{A maihda_summary object}

\item{top_n_labels}{Number of most extreme strata to label}
}
\value{
A ggplot2 object
}
\description{
Decomposes the total deviation from the overall mean into the additive (fixed) component
and the intersectional (random) component for each stratum.
}
\keyword{internal}
