% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/summary_maihda.R
\name{print.maihda_summary}
\alias{print.maihda_summary}
\title{Print method for maihda_summary objects}
\usage{
\method{print}{maihda_summary}(x, ...)
}
\arguments{
\item{x}{A maihda_summary object}

\item{...}{Additional arguments (not used)}
}
\value{
No return value, called for side effects.
}
\description{
Print method for maihda_summary objects
}
