% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/fit_maihda.R
\name{print.maihda_model}
\alias{print.maihda_model}
\title{Print method for maihda_model}
\usage{
\method{print}{maihda_model}(x, ...)
}
\arguments{
\item{x}{A maihda_model object}

\item{...}{Additional arguments}
}
\value{
No return value, called for side effects.
}
\description{
Print method for maihda_model
}
