% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/compare_maihda.R
\name{plot_comparison}
\alias{plot_comparison}
\title{Plot Model Comparison}
\usage{
plot_comparison(comparison_df)
}
\arguments{
\item{comparison_df}{A data frame from \code{compare_maihda()}.}
}
\value{
A ggplot2 object.
}
\description{
Creates a plot comparing VPC/ICC across multiple models.
}
\examples{
\donttest{
# Create strata and models using simulated data
strata_1 <- make_strata(maihda_sim_data, vars = c("gender", "race"))
strata_2 <- make_strata(maihda_sim_data, vars = c("gender", "race", "education"))

model1 <- fit_maihda(health_outcome ~ age + (1 | stratum), data = strata_1$data)
model2 <- fit_maihda(health_outcome ~ age + gender + (1 | stratum), data = strata_2$data)

comparison <- compare_maihda(model1, model2, bootstrap = TRUE)
plot_comparison(comparison)
}

}
