% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/calculate_pvc.R
\name{extract_between_variance}
\alias{extract_between_variance}
\title{Extract Between-Stratum Variance}
\usage{
extract_between_variance(model)
}
\arguments{
\item{model}{A maihda_model object}
}
\value{
Numeric value of between-stratum variance
}
\description{
Internal function to extract between-stratum variance from a MAIHDA model.
}
\keyword{internal}
